========================
Papers and Presentations
========================

------------------------------
Peer-reviewed journal articles
------------------------------

2023
----

Fiolleau, S., Uhlemann, S., Falco, N., & Dafflon, B. (2023). **Assessing probability of failure of urban landslides through rapid characterization of soil properties and vegetation distribution.** *Geomorphology,* 423, 108560, `https://doi.org/10.1016/j.geomorph.2022.108560 <https://doi.org/10.1016/j.geomorph.2022.108560>`__.

Rosier, I., Diels, J., Somers, B., & Van Orshoven, J. (2023). **The impact of vegetated landscape elements on runoff in a small agricultural watershed: A modelling study.** *Journal of Hydrology,* 129144, `https://doi.org/10.1016/j.jhydrol.2023.129144 <https://doi.org/10.1016/j.jhydrol.2023.129144>`__.

2022
----

Campforts, B., Shobe, C.M., Overeem, I., and Tucker, G.E. (2022) **The art of landslides: how stochastic
mass wasting shapes topography and influences landscape dynamics.** *Journal of Geophysical Research:
Earth Surface,* v. 127(8), e2022JF006745, `https://doi.org/10.1029/2022JF006745 <https://doi.org/10.1029/2022JF006745>`__.

Cardenas, B. T., Lamb, M. P., & Grotzinger, J. P. (2022). **Martian landscapes of fluvial ridges carved from ancient sedimentary basin fill.** *Nature Geoscience,* 1-7. `https://www.nature.com/articles/s41561-022-01058-2 <https://www.nature.com/articles/s41561-022-01058-2>`__.

Cullen, C., Anders, A. M., Lai, J., & Druhan, J. L. (2022). **Numerical modeling of groundwater‐driven stream network evolution in low‐relief post‐glacial landscapes.** *Earth Surface Processes and Landforms,* 47(2), 658-671, `https://doi.org/10.1002/esp.5278 <https://doi.org/10.1002/esp.5278>`__.

Gray, H. J., DuRoss, C. B., Nicovich, S. R., & Gold, R. D. (2022). **A geomorphic-process-based cellular automata model of colluvial wedge morphology and stratigraphy.** *Earth Surface Dynamics,* 10(2), 329-348, `https://doi.org/10.5194/esurf-10-329-2022 <https://doi.org/10.5194/esurf-10-329-2022>`__.

Kwang, J. S., Thaler, E. A., Quirk, B. J., Quarrier, C. L., & Larsen, I. J. (2022). **A Landscape Evolution Modeling Approach for Predicting Three‐Dimensional Soil Organic Carbon Redistribution in Agricultural Landscapes.** *Journal of Geophysical Research: Biogeosciences,* 127(2), e2021JG006616, `https://doi.org/10.1029/2021JG006616 <https://doi.org/10.1029/2021JG006616>`__.

Litwin, D. G., Tucker, G. E., Barnhart, K. R., & Harman, C. J. (2022). **Groundwater affects the geomorphic and hydrologic properties of coevolved landscapes.** *Journal of Geophysical Research: Earth Surface,* 127(1), e2021JF006239, `https://doi.org/10.1029/2021JF006239 <https://doi.org/10.1029/2021JF006239>`__.

Maneerat, P., Bürgmann, R., & Betka, P. M. (2022). **Thrust Sequence in the Western Fold-and-Thrust Belt of the Indo-Burma Range Determined from Fluvial Profile Analysis and Dynamic Landform Modeling.** *Tectonophysics,* 845, 229638, `https://doi.org/10.1016/j.tecto.2022.229638 <https://doi.org/10.1016/j.tecto.2022.229638>`__.

Reitman, N. G., Mueller, K. J., & Tucker, G. E. (2022). **Surface slip variability on strike‐slip faults.** *Earth Surface Processes and Landforms,* 47(4), 908-935, `https://doi.org/10.1002/esp.5294 <https://doi.org/10.1002/esp.5294>`__.

Tucker, G. E., Hutton, E. W., Piper, M. D., Campforts, B., Gan, T., Barnhart, K. R., ... & Syvitski, J. (2022). **CSDMS: a community platform for numerical modeling of Earth surface processes.** *Geoscientific Model Development,* 15(4), 1413-1439, `https://doi.org/10.5194/gmd-15-1413-2022 <https://doi.org/10.5194/gmd-15-1413-2022>`__.

Uhlemann, S., Dafflon, B., Wainwright, H. M., Williams, K. H., Minsley, B., Zamudio, K., ... & Hubbard, S. (2022). **Surface parameters and bedrock properties covary across a mountainous watershed: Insights from machine learning and geophysics.** *Science Advances,* 8(12), eabj2479.`https://doi.org/10.1126/sciadv.abj2479 <https://doi.org/10.1126/sciadv.abj2479>`__.

Xi, C., Hu, X., Ma, G., Rezania, M., Liu, B., & He, K. (2022). **Predictive model of regional coseismic landslides’ permanent displacement considering uncertainty.** *Landslides,* 19(10), 2513-2534, `https://doi.org/10.1007/s10346-022-01918-3 <https://doi.org/10.1007/s10346-022-01918-3>`__.

Zhao, H., Lin, Y., Zhou, J., Delang, C. O., & He, H. (2022). **Simulation of Holocene soil erosion and sediment deposition processes in the Yellow River basin during the Holocene.** *Catena,* 219, 106600, `https://doi.org/10.1016/j.catena.2022.106600 <https://doi.org/10.1016/j.catena.2022.106600>`__.

2021
----

Barnhart, K. R., Jones, R. P., George, D. L., McArdell, B. W., Rengers, F. K., Staley, D. M., & Kean, J. W. (2021). **Multi‐Model Comparison of Computed Debris Flow Runout for the 9 January 2018 Montecito, California Post‐Wildfire Event.** *Journal of Geophysical Research: Earth Surface,* 126(12), e2021JF006245.`https://doi.org/10.1029/2021JF006245 <https://doi.org/10.1029/2021JF006245>`__.

Chen, H., Wang, X., Lu, H., & Van Balen, R. (2021). **Anthropogenic impacts on Holocene fluvial dynamics in the Chinese Loess Plateau, an evaluation based on landscape evolution modelling.** *Geomorphology,* 392, 107935, `https://doi.org/10.1016/j.geomorph.2021.107935 <https://doi.org/10.1016/j.geomorph.2021.107935>`__.

Garcia-Estève, C., Caniven, Y., Cattin, R., Dominguez, S., & Sylvain, R. (2021). **Morphotectonic Evolution of an Alluvial Fan: Results of a Joint Analog and Numerical Modeling Approach.** *Geosciences,* 11(10), 412, `https://doi.org/10.3390/geosciences11100412 <https://doi.org/10.3390/geosciences11100412>`__.

Hooshyar, M., & Porporato, A. (2021). **Mean Dynamics and Elevation‐Contributing Area Covariance in Landscape Evolution Models.** *Water Resources Research,* 57(8), e2021WR029727, `https://doi.org/10.1029/2021WR029727 <https://doi.org/10.1029/2021WR029727>`__.

Lai, J., & Anders, A. M. (2021). **Climatic controls on mountain glacier basal thermal regimes dictate spatial patterns of glacial erosion.** *Earth Surface Dynamics*, 9(4), 845-859, `https://doi.org/10.5194/esurf-9-845-2021 <https://doi.org/10.5194/esurf-9-845-2021>`__.

Lipp, A. G., & Roberts, G. G. (2021). **Scale‐Dependent Flow Directions of Rivers and the Importance of Subplate Support.** *Geophysical Research Letters,* 48(1), e2020GL091107, `https://doi.org/10.1029/2020GL091107 <https://doi.org/10.1029/2020GL091107>`__.

Lipp, A. G., Roberts, G. G., Whittaker, A. C., Gowing, C. J., & Fernandes, V. M. (2021). **Source region geochemistry from unmixing downstream sedimentary elemental compositions.** *Geochemistry, Geophysics, Geosystems,* 22(10), e2021GC009838, `https://doi.org/10.1029/2021GC009838 <https://doi.org/10.1029/2021GC009838>`__.

O’Malley, C. P. B., White, N. J., Stephenson, S. N., & Roberts, G. G. (2021). **Large‐scale tectonic forcing of the African landscape.** *Journal of Geophysical Research: Earth Surface,* 126(12), e2021JF006345 https://doi.org/10.1029/2021JF006345.

Pan, B., Cai, S., & Geng, H. (2021). **Numerical simulation of landscape evolution and mountain uplift history constrain-A case study from the youthful stage mountains around the central Hexi Corridor, NE Tibetan Plateau.** *Science China Earth Sciences,* 1-13, `https://doi.org/10.1007/s11430-020-9716-6 <https://doi.org/10.1007/s11430-020-9716-6>`__.

Quichimbo, E. A., Singer, M. B., Michaelides, K., Hobley, D. E., Rosolem, R., & Cuthbert, M. O. (2021). **DRYP 1.0: a parsimonious hydrological model of DRYland Partitioning of the water balance.** *Geoscientific Model Development,* 14(11), 6893-6917, `https://doi.org/10.5194/gmd-14-6893-2021 <https://doi.org/10.5194/gmd-14-6893-2021>`__.

Sharma, H., Ehlers, T. A., Glotzbach, C., Schmid, M., & Tielbörger, K. (2021). **Effect of rock uplift and Milankovitch timescale variations in precipitation and vegetation cover on catchment erosion rates.** *Earth Surface Dynamics,* 9(4), 1045-1072, `https://doi.org/10.5194/esurf-9-1045-2021 <https://doi.org/10.5194/esurf-9-1045-2021>`__.

Sheehan, C. E., & Ward, D. J. (2021). **An Autogenic Cycle of Fluvial Transience in Dipping, Layered Rocks.** *Geophysical Research Letters,* 48(1), e2020GL090246, `https://doi.org/10.1029/2020GL090246 <https://doi.org/10.1029/2020GL090246>`__.

Shen, H., Lynch, B., Poulsen, C. J., & Yanites, B. J. (2021). **A modeling framework (WRF-Landlab) for simulating orogen-scale climate-erosion coupling.** *Computers & Geosciences,* 146, 104625, `https://doi.org/10.1016/j.cageo.2020.104625 <https://doi.org/10.1016/j.cageo.2020.104625>`__.

Spencer, B. M., Thigpen, J. R., Gallen, S. F., Dortch, J. M., Hodges, K. V., Law, R. D., & Mako, C. A. (2021). **An Evaluation of Erosional‐Geodynamic Thresholds for Rapid Orogenic Denudation.** *Journal of Geophysical Research: Solid Earth,* 126(12), e2021JB022353, `https://doi.org/10.1029/2021JB022353 <https://doi.org/10.1029/2021JB022353>`__.

2020
----

Anand, S. K., Hooshyar, M., & Porporato, A. (2020). **Linear layout of multiple flow-direction networks for landscape-evolution simulations.** *Environmental Modelling & Software,* 133, 104804, `https://doi.org/10.1016/j.envsoft.2020.104804 <https://doi.org/10.1016/j.envsoft.2020.104804>`__.

Barnhart, K.R., Hutton, E.W.H., Tucker, G.E., Gasparini, N.M., Istanbulluoglu, E., Hobley, D.E.J., Lyons⁠, N.J., Mouchene, M., Nudurupati, S.S., Adams, J.M., and Bandaragoda, C. (2020) **Short communication: Landlab 2.0: A software package for Earth surface dynamics.** *Earth Surface Dynamics,* 8, 379–397, `doi:10.5194/esurf-8-379-2020 <https://doi.org/10.5194/esurf-8-379-2020>`__.

Barnhart, K. R., Tucker, G. E., Doty, S. G., Glade, R. C., Shobe, C. M., Rossi, M. W., & Hill, M. C. (2020). **Projections of landscape evolution on a 10,000 year timescale with assessment and partitioning of uncertainty sources.** *Journal of Geophysical Research: Earth Surface,* 125(12), e2020JF005795, `https://doi.org/10.1029/2020JF005795 <https://doi.org/10.1029/2020JF005795>`__.

Barnhart, K. R., Tucker, G. E., Doty, S., Shobe, C. M., Glade, R. C., Rossi, M. W., & Hill, M. C. (2020). **Inverting topography for landscape evolution model process representation: Part 1, conceptualization and sensitivity analysis.** *Journal of Geophysical Research: Earth Surface,* e2018JF004961. `https://doi.org/10.1029/2018JF004961 <https://doi.org/10.1029/2018JF004961>`__.

Barnhart, K. R., Tucker, G. E., Doty, S., Shobe, C. M., Glade, R. C., Rossi, M. W., & Hill, M. C. (2020). **Inverting topography for landscape evolution model process representation: Part 2, calibration and validation.** *Journal of Geophysical Research: Earth Surface,* e2018JF004963. `https://doi.org/10.1029/2018JF004963 <https://doi.org/10.1029/2018JF004963>`__.

Barnhart, K. R., Tucker, G. E., Doty, S., Shobe, C. M., Glade, R. C., Rossi, M. W., & Hill, M. C. (2020). **Inverting topography for landscape evolution model process representation: Part 3, Determining parameter ranges for select mature geomorphic transport laws and connecting changes in fluvial erodibility to changes in climate.** *Journal of Geophysical Research: Earth Surface,* e2019JF005287, `https://doi.org/10.1029/2019JF005287 <https://doi.org/10.1029/2019JF005287>`__.

Carriere, A., Le Bouteiller, C., Tucker, G.E., Klotz, S., and Naaim, M. (2020) **Impact of vegetation on erosion: Insights from the calibration and test of a landscape evolution model in alpine badland catchments.** *Earth Surface Processes and Landforms.* `https://doi.org/10.1002/esp.4741 <https://doi.org/10.1002/esp.4741>`__.

Evans, M. J., Scheele, B. C., Westgate, M. J., Yebra, M., Newport, J. S., & Manning, A. D. (2020). Beyond the pond: Terrestrial habitat use by frogs in a changing climate. Biological Conservation, 249, 108712., `https://doi.org/10.1016/j.biocon.2020.108712 <https://doi.org/10.1016/j.biocon.2020.108712>`__.

Lai, J., & Anders, A. M. (2020). **Tectonic controls on rates and spatial patterns of glacial erosion through geothermal heat flux.** *Earth and Planetary Science Letters,* 543, 116348, `https://doi.org/10.1016/j.epsl.2020.116348 <https://doi.org/10.1016/j.epsl.2020.116348>`__.

Lipp, A. G., Roberts, G. G., Whittaker, A. C., Gowing, C. J., & Fernandes, V. M. (2020). **River sediment geochemistry as a conservative mixture of source regions: Observations and predictions from the Cairngorms, UK.** *Journal of Geophysical Research: Earth Surface,* 125(12), `https://doi.org/10.1029/2020JF005700 <https://doi.org/10.1029/2020JF005700>`__.

Litwin, D.G., Tucker, G.E., Barnhart, K.R., and Harman, C.J. (2020) **GroundwaterDupuitPercolator: A Landlab component for groundwater flow,** *Journal of Open Source Software,* 5(46), 1935, `https://doi.org/10.21105/joss.01935 <https://doi.org/10.21105/joss.01935>`__.

Lyons, N.J., Albert, J.S., and Gasparini, N.M. (2020). **SpeciesEvolver: A Landlab component to evolve life in simulated landscapes.** *Journal of Open Source Software,* 5(46), 2066, `https://doi.org/10.21105/joss.02066 <https://doi.org/10.21105/joss.02066>`__.

Lyons, N. J., Val, P., Albert, J. S., Willenbring, J. K., & Gasparini, N. M. (2020). **Topographic controls on divide migration, stream capture, and diversification in riverine life.** *Earth Surface Dynamics,* 8(4), 893-912, `https://doi.org/10.5194/esurf-8-893-2020 <https://doi.org/10.5194/esurf-8-893-2020>`__.

Pfeiffer, A.M., Barnhart, K.R., Czuba, J.A., and Hutton, E.W.H. (2020). **NetworkSedimentTransporter: A Landlab component for bed material transport through river networks.** *Journal of Open Source Software,* 5(53), 2341, `https://doi.org/10.21105/joss.02341 <https://doi.org/10.21105/joss.02341>`__.

Sheehan, C.E., and Ward, D.J. (2020). **Migrating Transverse Escarpments in Strike Valleys on the Colorado Plateau.** *Journal of Geophysical Research: Earth Surface,* 125(3), e2019JF005260, `https://doi.org/10.1029/2019JF005260 <https://doi.org/10.1029/2019JF005260>`__.

Tucker, G. E., Hobley, D.E.J., McCoy, S.W., and Struble, W.T. (2020) **Modeling the shape and evolution of normal-fault facets.** *Journal of Geophysical Research: Earth Surface,* 125, `https://doi.org/10.1029/2019JF005305 <https://doi.org/10.1029/2019JF005305>`__.

Walker, S. J., Wilkinson, S. N., van Dijk, A. I., & Hairsine, P. B. (2020). **A multi-resolution method to map and identify locations of future gully and channel incision.** *Geomorphology,* 358, 107115, `https://doi.org/10.1016/j.geomorph.2020.107115 <https://doi.org/10.1016/j.geomorph.2020.107115>`__.

2019
----

Baldazo, D., Parras, J., & Zazo, S. (2019). **Decentralized multi-agent deep reinforcement learning in swarms of drones for flood monitoring.** In *2019 27th European Signal Processing Conference (EUSIPCO)* (pp. 1-5). IEEE.

Bandaragoda, C. J., Castronova, A., Istanbulluoglu, E., Strauch, R.,
Nudurupati, S. S., Phuong, J., Adams, J.M., Gasparini, N.M., Barnhart,
K.R., Hutton, E.W.H., Hobley, D.E.J., Lyons, N.J., Tucker, G.E.,
Tarboton, D.G., Idaszak, R., and Wang S. (2019). **Enabling
collaborative numerical Modeling in Earth sciences using Knowledge
Infrastructure.** *Environmental Modelling & Software*,
`doi:10.1016/j.envsoft.2019.03.020 <https://linkinghub.elsevier.com/retrieve/pii/S1364815219301562>`__.

Barnhart, K. R., Glade, R. C., Shobe, C. M., and Tucker, G. E. (2019)
**Terrainbento 1.0: a Python package for multi-model analysis in
long-term drainage basin evolution.** *Geosci. Model Dev.*, v. 12,
p. 1267-1297, `doi:10.5194/gmd-12-1267-2019 <https://www.geosci-model-dev.net/12/1267/2019/>`__.

Barnhart, K.R., Hutton, E., and Tucker, G.E. (2019) **umami: a Python package for Earth surface dynamics objective function construction**, *Journal of Open Source Software*, 4(42), 1776, `doi:10.21105/joss.01776 <https://doi.org/10.21105/joss.01776>`__.

Glade, R.C.*, Shobe, C.M.*, Anderson, R.S., and Tucker, G.E. (2019)
**Canyon shape and erosion dynamics governed by channel-hillslope
feedbacks.** *Geology*,
`doi:10.1130/G46219.1 <https://pubs.geoscienceworld.org/gsa/geology/article/47/7/650/570313/Canyon-shape-and-erosion-dynamics-governed-by>`__. \*Equal
contributions

Phuong J., C. Bandaragoda, E. Istanbulluoglu, C. Beveridge, R. Strauch,
L. Setiawan, and S. D. Mooney (2019). **Automated retrieval,
preprocessing, and visualization of gridded hydrometeorology data
products for spatial-temporal exploratory analysis and
intercomparison.** Environmental Modeling and Software. Vol 116.
p. 119-30: https://linkinghub.elsevier.com/retrieve/pii/S136481521830865X.

Reitman, N.G., Mueller, K.J., Tucker, G.E., Gold, R.D., Briggs, R.D., and Barnhart, K.R. (2019) **Landscape Evolution Models Demonstrate that Offset Channels are Incomplete Records of Strike-Slip Fault Displacement.** *Journal of Geophysical Research: Solid Earth*, 124, `doi:10.1029/2019JB018596 <https://doi.org/10.1029/2019JB018596>`__.

Sharman, G. R., Sylvester, Z., & Covault, J. A. (2019). **Conversion of
tectonic and climatic forcings into records of sediment supply and
provenance.** *Scientific Reports*, 9(1), 4115,
`doi:10.1038/s41598-019-39754-6 <https://www.nature.com/articles/s41598-019-39754-6>`__.

Zebari, M., Grützner, C., Navabpour, P., & Ustaszewski, K. (2019).
**Relative timing of uplift along the Zagros Mountain Front Flexure
(Kurdistan Region of Iraq): Constrained by geomorphic indices and
landscape evolution modeling.** *Solid Earth*, 10(3), 663-682
`doi:10.5194/se-10-663-2019 <https://www.solid-earth.net/10/663/2019/>`__.

2018
----

Barnhart, K. R., Hutton, E. W., Gasparini, N. M., & Tucker, G. E.
(2018). **Lithology: A Landlab submodule for spatially variable rock
properties.** *J. Open Source Software*, 3(30), 979,
`doi:10.21105/joss.00979 <https://joss.theoj.org/papers/10.21105/joss.00979>`__

Lai J., and Anders, A. (2018) **Modeled Postglacial Landscape Evolution
at the Southern Margin of the Laurentide Ice Sheet: Hydrological
Connection of Uplands Controls the Pace and Style of Fluvial Network
Expansion.** *Journal of Geophysical Research: Earth Surface*, v. 123, no. 5,
p. 967-984, `doi:10.1029/2017JF004509 <https://agupubs.onlinelibrary.wiley.com/doi/full/10.1029/2017JF004509>`__

Langston, A.L., and Tucker, G. E. (2018) **Developing and exploring a
theory for the lateral erosion of bedrock channels for use in landscape
evolution models.** *Earth Surface Dynamics*, v. 6, p. 1-27,
doi:10.5194/esurf-6-1-2018.
`abstract  <https://www.earth-surf-dynam.net/6/1/2018/>`__
`paper  <https://www.earth-surf-dynam.net/6/1/2018/esurf-6-1-2018.pdf>`__

Pelletier, J.D., Barron-Gafford, G.A., Guttierez-Jurado, H., Hinckley,
E.S., Istanbulluoglu, E., McGuire, L.A., Niu G.-Y. Poulos, M.J.,
Rasmussen, C., Richardson, P., Swetnam, T.L., and Tucker, G.E. (2018)
**Which way do you lean? Using slope aspect variations to understand
Critical Zone processes and feedbacks.** *Earth Surface Processes and
Landforms*, doi:10.1002/esp.4306.
`abstract <https://onlinelibrary.wiley.com/doi/abs/10.1002/esp.4306>`__
`paper <https://onlinelibrary.wiley.com/doi/epdf/10.1002/esp.4306>`__

Schmid, M., Ehlers, T.A., Werner, C., Hickler, T., and Fuentes-Espoz, J.
P. (2018). **Effect of changing vegetation and precipitation on
denudation–Part 2: Predicted landscape response to transient climate and
vegetation cover over millennial to million-year timescales.** *Earth
Surface Dynamics*, 6(4), 859-881,
`doi:10.5194/esurf-6-859-2018 <https://www.earth-surf-dynam.net/6/859/2018/>`__.

Singer, M. B., Michaelides, K., & Hobley, D. E. J. (2018) **STORM 1.0: a
simple, flexible, and parsimonious stochastic rainfall generator for simulating
climate and climate change.** *Geoscientific Model Development*,  11, 3713–3726,
`https://doi.org/10.5194/gmd-11-3713-2018 <https://doi.org/10.5194/gmd-11-3713-2018>`__.

Strauch, R.E., Istanbulluoglu, E., Nudurupati, S.S., Bandaragoda, C.,
Gasparini, N.M., & Tucker, G.E. (2018) **A hydro-climatological approach
to predicting regional landslide probability using Landlab.** *Earth
Surface Dynamics*, v. 6, p. 49-75, doi:10.5194/esurf-6-49-2018.
`abstract <https://www.earth-surf-dynam.net/6/49/2018/>`__
`paper <https://www.earth-surf-dynam.net/6/49/2018/esurf-6-49-2018.pdf>`__

Tucker, G. E., McCoy, S.W., and Hobley, D.E.J. (2018) **A lattice grain
model of hillslope evolution.** *Earth Surface Dynamics*, v. 6,
p. 563-582, doi: 10.5194/esurf-6-563-2018.
`abstract and paper <https://www.earth-surf-dynam.net/6/563/2018/>`__


2017
----

Adams, J.M., Gasparini, N.M., Hobley, D.E.J., Tucker, G.E., Hutton,
E.W.H., Nudurupati, S.S., and Istanbulluoglu, E. **The Landlab v1.0
OverlandFlow component: a Python tool for computing shallow-water flow
across watersheds.** *Geoscientific Model Development*, 2017,
doi:10.5194/gmd-10-1645-2017.
`abstract <https://www.geosci-model-dev.net/10/1645/2017/gmd-10-1645-2017.html>`__
`paper <https://www.geosci-model-dev.net/10/1645/2017/gmd-10-1645-2017.pdf>`__

Gray, H.J., Shobe, C.M., Hobley, D.E.J., Tucker, G.E., Duvall, A.R.,
Harbert, S.A., and Owen, L.A. (2017) **Off-fault deformation rate along
the southern San Andreas fault at Mecca Hills, southern California,
inferred from landscape modeling of curved drainages.** *Geology*, v.
46(1), p. 59-62, doi: 10.1130/G39820.1.
`abstract and paper <https://pubs.geoscienceworld.org/gsa/geology/article-abstract/46/1/59/522872/Off-fault-deformation-rate-along-the-southern-San?redirectedFrom=fulltext>`__

Hobley, D.E.J., Adams, J.M., Nudurupati, S.S., Hutton, E.W.H, Gasparini,
N.M., Istanbulluoglu, E., and Tucker, G.E., **Creative computing with
Landlab: an open-source toolkit for building, coupling, and exploring
two-dimensional numerical models of Earth-surface dynamics.** *Earth
Surface Dynamics*, 2017, doi:10.5194/esurf-5-21-2017.
`abstract <https://www.earth-surf-dynam.net/5/21/2017/>`__
`paper <https://www.earth-surf-dynam.net/5/21/2017/esurf-5-21-2017.pdf>`__

Shobe, C.M., Tucker, G.E., and Barnhart, K.R. **The SPACE 1.0 model: a
Landlab component for 2-D calculation of sediment transport, bedrock
erosion, and landscape evolution.** *Geoscientific Model Development*,
2017, doi:10.5194/gmd-10-4577-2017.
`abstract <https://www.geosci-model-dev.net/10/4577/2017/>`__
`paper <https://www.geosci-model-dev.net/10/4577/2017/gmd-10-4577-2017.pdf>`__

2016
----

Tucker, G.E., Hobley, D.E.J., Hutton, E., Gasparini, N.M.,
Istanbulluoglu, E., Adams, J.M., and Nudurupati, S.S. **CellLab-CTS
2015: continuous-time stochastic cellular automaton** **modeling using
Landlab.** *Geoscientific Model Development*, February 2016.
`abstract <https://www.geosci-model-dev.net/9/823/2016/>`__
`paper <https://www.geosci-model-dev.net/9/823/2016/gmd-9-823-2016.pdf>`__

Wickert, A.D. **Open-source modular solutions for flexural isostasy:
gFlex v1.0.** *Geoscientific Model Development*, 9, 997-1017,
doi:10.5194/gmd-9-997-2016, 2016.
`abstract <https://www.geosci-model-dev.net/9/997/2016/>`__
`paper <https://www.geosci-model-dev.net/9/997/2016/gmd-9-997-2016.pdf>`__

------------------------------------
Peer-reviewed conference proceedings
------------------------------------

Adams, J.M., Nudurupati, S.S., Gasparini, N.M., Hobley, D.E.J., Hutton,
E., Tucker, G.E., and Istanbulluoglu, E. (2014) **Landlab: Sustainable
Software Development in Practice. Proceedings of 2nd Workshop on
Sustainable Software for Science: Practice and Experiences.**
`paper <https://figshare.com/articles/Landlab_Sustainable_Software_Development_in_Practice/1097629>`__

-----
Press
-----

`Grad student helps build model to study wildfires. <https://news.tulane.edu/news/grad-student-helps-build-model-study-wildfires>`__
Benjamin Morris, *New Wave: Tulane News*. November 11, 2016.
`article <https://news.tulane.edu/news/grad-student-helps-build-model-study-wildfires>`__

----------------------------------
Theses, Dissertations, and Reports
----------------------------------

2020
----

Lai, J. (2020). **Constraining tectonic and climatic controls on glacial/postglacial landscape evolution using numerical modeling** (Doctoral dissertation, University of Illinois at Urbana-Champaign).

2018
----

Mahmoudi, M. (2018). **Comparing model predictions of hillslope sediment size distribution with field measurements** (Doctoral dissertation, San Francisco State University).


-------------
Presentations
-------------

2020
----



2019
----

Adams, J.M., Overeem, I., Hutton, E., Kettner, A.K. and Tucker, G.E. (2019, June) Exploring Surface Processes Using the Community Surface Dynamics Modeling System Modeling Tools. Joint Federal Interagency Sedimentation and Hydrology Conference (SEDHYD), Reno, NV.

Bandaragoda, C., Castronova, A.M., Istanbulluoglu, E., Strauch, R.L., Nudurupati, S.S., Phoung, J., Adams, J.M., Gasparini, N.M., Barnhart, K.B., Hutton, E., Hobley, D.E., Lyons, N.J., Tucker, G.E., Tarboton, D.G., Idaszak, R. and Wang, S.W. (2019, December) Enabling collaborative numerical modeling in hydrology using knowledge infrastructure. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Barnhart, K.R., Tucker, G.E., Doty, S., Shobe, C.M., Glade, R.C., Rossi, M.W., and Hill, M.C. (2019, August) Projections of erosion for a temperate watershed on a 10,000 year timescale. Paper presented at Goldschmidt conference, Barcelona, Spain.

Barnhart, K.R., Tucker, G.E., Doty, S., Shobe, C.M., Glade, R.C., Rossi, M.W., and Hill, M.C. (2019, December) The importance and challenge of thresholds in calibrating landscape evolution models. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Barnhart, K.R., Tucker, G.E., Doty, S., Shobe, C.M., Glade, R.C., Rossi, M.W., and Hill, M.C. (2019, December) Uncertainty in the prediction of erosion on geologic time scales. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Carriere, A., Le Bouteiller, C., Tucker, G.E. and Naaim, M (2019, April) Vegetation-modulated erosion in badland catchments. Paper presented at European Geophysical Union general assembly, Vienna Austria

Gasparini, N.M., Adams, J.M. Bandaragoda, C., Barnhart, K.R., Hobley, D.E., Hutton, E., Istanbulluoglu, E., Lyons, N.J., Mouchene, M., Nudurupati, S.S., Strauch, R.L. and Tucker, G.E. (2019, December) Tools for learning about earth surface processes and how to model them. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Gemperline, J., Tucker, G.E., Rossi, M.W. and Hynek, B.M. (2019, December) Initial landscape evolution model results for Martian valley networks show potential differences between distributed rainfall and a melting ice sheet. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Glade, R., Shobe, C.M., Anderson, R.S. and Tucker, G.E. (2019, December) How do channel-hillslope feedbacks modulate river canyon evolution? Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Gray, HJ, East, AE, and Mahan, S (2019, December) Potential Aeolian Sediment Transport Pathways, Provenance, and Landscape Evolution in the Chuckwalla Valley, Southeastern California. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Istanbulluoglu, E, Strauch, RL, and Riedel, JL (2019, December) A new approach to mapping landslide hazards: a probabilistic integration of empirical and process-based models. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Litwin, D., Harman, C.J., Tucker, G.E. and Barnhart, K.R. (2019, December) A numerical exploration of coevolution between runoff pathways, climate and landscape morphology. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Lyons, NJ, Val, P, Albert, JS, Willenbring, JK, and Gasparini, NM (2019, December) Linking life and landscapes with new modeling tools. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Mason, JA, McDowell, T, and Marin-Spiotta, E (2019, December) Aeolian Landforms on Loess Tablelands of the Great Plains Limit Connectivity of Surface Runoff and Sediment Transport to Surrounding Stream Networks, Potentially Enhancing Long-Term Sediment and Carbon Storage. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Reitman, N.G., Mueller, K.J., Tucker, G.E., Gold, R.D., Briggs, R.W. and Barnhart, K.R. (2019, December) Offset channels are incomplete records of strike-slip fault displacement. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Steckler, M.S., Hutton, E., Ologan, D., Tucker, G.E., Grall, C. and Gurcay, S. (2019, December) Developing Sequence Stratigraphic Modeling in Landlab to improve understanding of the tectonics in the Gulf of Kusadasi, Turkey. Gasparini, N.M., Adams, J.M. Bandaragoda, C., Barnhart, K.R., Hobley, D.E., Hutton, E., Istanbulluoglu, E., Lyons, N.J., Mouchene, M., Nudurupati, S.S., Strauch, R.L. and Tucker, G.E. (2019, December) Tools for learning about earth surface processes and how to model them. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Strauch, RL, Bandaragoda, C, Cristea, NC, Raymond, C, Istanbulluoglu, E, and Miller, D (2019, December)
Slippery future predictions of multiple mountain hazards: landslides, climate change, and wildfire. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.

Tucker, G.E. (2019, March) Testing landscape evolution models with topographic data. Invited lecture presented at workshop on Data ANalytics for Climate and Earth, Lake Arrowhead, CA.

Tucker, G.E. (2019, October) Community, Computing, and Education: an overview of CSDMS. Recorded lecture provided for 2019 CoMSES Virtual Meeting.

Tucker, G.E., Barnhart, K.R., Doty, S.G., Glade, R.C., Hill, M.C., Rossi, M.W. and Shobe, C.M. (2019, November) Testing long-term channel network incision models using a natural experiment in postglacial landscape evolution. Paper presented at River, Coastal and Estuarine Morphodynamics Symposium (RCEM), Auckland, New Zealand.

Tucker, G.E., Hobley, D.E.J., and McCoy, S.W. (2019, December) Exploring the morphologic diversity of normal-fault facets. Paper presented at American Geophysical Union fall meeting, San Francisco, CA.


2018
----

Barnhart, K.R., Tucker, G.E., Doty, S., Hill, M.C., Rossi, M.W., Shobe, C.M., and Glade, R.C. (2018, June) Uncertainty in the prediction of erosion on geologic time scales. Paper presented at International Congress on Environmental Modeling and Software, Fort Collins, CO.

Barnhart, K.R., Tucker, G.E., Doty, S.G., Hill, M.C., Rossi, M.W., Shobe, C.M., and Glade, R.C. (2018, December) Inverting topography for landscape evolution model process representation. Paper presented at American Geophysical Union fall meeting, Washington, DC.

Carriere, A., Le Bouteiller, C., Tucker, G., and Naaim, M. (2018, April) How does vegetation impact the erosion by modelling landscape evolution of marly catchments in the Southern Alps of France? Paper presented at European Geosciences Union General Assembly.

Hobley, D., Gasparini, N., Bandaragoda, C., Barnhart, K., Adams, J., and Tucker, G. (2018, September) How can the Landlab modelling toolkit help in communicating geomorphology? Paper presented at British Society for Geomorphology, Aberystwyth, UK.

Istanbulluoglu E., Strauch R., Nudurupati S.S., Bandaragoda C.,
Gasparini N.M., and G.E. Tucker (2018). A hydro-climatological approach
to predicting regional landslide probability using Landlab. Community
Surface Dynamics Modeling systems Annual Meeting, Boulder CO, May, 2018.

Lyons N.J., Bandaragoda C., Barnhart K.R., Gasparini N.M., Hobley
D.E.J., Hutton E., Istanbulluoglu E., Mouchene M., Siddhartha Nudurupati
S., Tucker G.E., (2018). Recent Advances in Landlab, a Software Toolkit
for Modeling Earth Surface Dynamics. Pardee Keynote Symposia, GSA
National Meeting, November 4–7, 2018, Indianapolis, IN.
`abstract <https://gsa.confex.com/gsa/2018AM/webprogram/Paper324626.html>`__
`poster <https://drive.google.com/file/d/16_hRtF6DsBKQGSHE3E2zkYUwovUQEiVZ/view?usp=drive_open>`__

Mouchene, M., Tucker, G.E., Barnhart, K.R., and Gasparini, N.M. (2018, December) The Clast-Tracker: a new tool for numerical modeling of the motion of individual particles. Paper presented at American Geophysical Union fall meeting, Washington, DC.

Reitman, N., Mueller, K.J., and Tucker, G.E. (2018, December) Are offset channels accurate representations of strike-slip fault displacement? Implications from landscape evolution modeling. Paper presented at American Geophysical Union fall meeting, Washington, DC.

Shobe, C.M., Glade, R.C., Tucker, G.E., and Anderson, R.S. (2018, December) Chaotic Chasms: Canyon Evolution Governed by Autogenic Channel-Hillslope Feedbacks. Paper presented at American Geophysical Union fall meeting, Washington, DC.

Tucker, G.E. (2018, January) Tales from Computational Geomorphology. Lecture presentation at Knuth80: Algorithms, Combinatorics, Information; Piteå, Sweden.

Tucker, G.E., McCoy, S.W., and Hobley, D.E.J. (2018, April) A Landlab-built cellular automaton model of hillslope evolution. Paper presented at SI2 Principal Investigators’ meeting, Washington, DC.

Tucker, G.E., Barnhart, K.R., Bandaragoda, C., Gasparini, N.M., Hobley, D.E.J., Hutton, E., Istanbulluoglu, E., Mouchene, M., and Siddhartha Nudurupati, S. (2018, June) Design and applications of Landlab: a modular Python-language framework for building 2D numerical models of earth-surface processes. Paper presented at International Congress on Environmental Modeling and Software, Fort Collins, CO.

Tucker, G.E., Barnhart, K.R., Doty, S.G., Glade, R.C., Hill, M.C., Rossi, M., Shobe, C.M. (2018, August) Landlab meets Lidar: Using digital topography to test and calibrate long-term erosion models. Invited keynote lecture, Geomorphometry 2018, Boulder, Colorado.

Tucker, G.E., McCoy, S.W., and Hobley, D.E.J. (2018, December) A Stochastic Cellular Model of Hillslope Morphology and Evolution. Paper presented at American Geophysical Union fall meeting, Washington, DC.

2017
----

Adams, J. (2017) Nonsteady flow routing in Landlab: implications for
modeling watershed evolution, Tulane Science and Engineering Research
Days, New Orleans, Louisiana, April, 2017.
` Poster tied for top graduate contribution <https://news.tulane.edu/news/outstanding-researchers-recognized-sse-research-day>`__

Adams, J.M. (2017) Integrating and applying a 2-D hydrodynamic model in
a landscape evolution framework. United States Naval Research
Laboratory, National Aeronautics and Space Administration (NASA) John C.
Stennis Space Center, Mississippi, January 2017.

Adams, J.M., Gasparini, N.M., Tucker, G.E., and Istanbulluoglu, E.
(2017, May) The competition between frequent and rare flood events: the
impact on erosion rates and landscape form. Poster presented at Joint
CSDMS-COMSESnet-SEN Meeting: Modeling Coupled Earth and Human Systems,
Boulder, Colorado.

Bandaragoda, C.J., Castronova, A., Phuong, J., Strauch, R.,
Istanbulluoglu, E., Nudurupati, S.S., Tarboton, D., Yin, D., Wang, S,
Barnhart, K., Tucker, G.E., Hutton, E.W.H., Hobley D.E.J., Gasparini,
N.M., Adams, J.M. (2017) Reproducible Earth-surface modeling with
Landlab on HydroShare, EarthCube All-Hands Meeting 2017, Seattle,
Washington, June, 2017
`abstract <https://www.hydroshare.org/resource/38002ee4bf594901a29055bdf20b13da>`__
:download:`poster <user_guide/images/Bandaragoda_ECAHM2017_HydroShare_Landlab_Poster.pdf>`

Bandaragoda, C.J., Castronova, A., Phuong, J., Strauch, R.,
Istanbulluoglu, E., Nudurupati*, S.S., Barnhart**, K., Gasparini, N.M.,
Tarboton, D., Yin, D., Wang, S., Tucker, G.E., Hutton, E.W.H., Hobley,
D.E.J., Adams, J.M. \* (2017, December) Lowering the barriers to
computational modeling of Earth's surface: coupling Jupyter Notebooks
with Landlab, HydroShare, and CyberGIS for research and education.
Poster presented at American Geophysical Union fall meeting, New
Orleans, LA.

Bandaragoda, C.J., Phuong, J., Mooney, S., Stephens, K., Istanbulluoglu,
E., Pieper, K., Rhodes, W., Edwards, M., Pruden, A., Bales, J., Clark,
E., Brazil, L., Leon, M., McDowell, W.G., Horsburgh, J.S., Tarboton,
D.G., Jones, A.S., Hutton, E., Tucker, G.E., McCready, L., Peckham,
S.D., Lenhardt, W.C., and Idaszak, R. (2017, December) Building
infrastructure to prevent disasters like Hurricane Maria. Paper
presented at American Geophysical Union fall meeting, New Orleans, LA.

Barnhart, K., Tucker, G., Hobley, D., Hutton, E. (2017) Landlab
components for surface hydrology: the FlowAccumulator and the
FlowDirectors, CSDMS Annual Meeting, Modeling Coupled Earth and Human
Systems - The Dynamic Duo, Boulder, Colorado, May, 2017.
`abstract <https://csdms.colorado.edu/wiki/Annualmeeting:2017_CSDMS_meeting-053>`__

Carriere, A., Le Bouteiller, C., Tucker, G., and Naaim, M. (2017,
April). Modelling the impact of vegetation on marly catchments in the
Southern Alps of France. In EGU General Assembly Conference Abstracts
(Vol. 19, p. 14136).

Gasparini, N.M., Lyons, N., Brocard, G., Wehrs, K., Willenbring, J.,
Crosby, B., Adams, J.M., Hobley, D.E.J., Hutton, E.W.H., Nudurupati,
S.S., Istanbulluoglu, E., Tucker, G.E., Knuth, J., Barnhart, K.,
Mouchene, M., Strauch, R., Bandaragoda, C. (2017) Using the Landlab
modeling toolkit to undertand earth surface dynamics in CZOs, Critical
Zone Science: Current Advances and Future Opportunities, Arlington, VA,
June, 2017.

Gasparini, N.M., Adams, J.M. (2017) Integrating and applying a 2-D
hydrodynamic model in a landscape evolution framework. Indiana
University Bloomington, Department of Earth and Atmospheric Sciences,
February, 2017.

Glaubius J., Li, X., Maerker, M. (2017) The Agricultural Terraces Model
(AgrTerrModel): Exploring Human-Environment Interactions in Terraced
Landscapes, Modeling Coupled Earth and Human Systems - The Dynamic Duo,
Boulder, Colorado, May, 2017.
`abstract <https://csdms.colorado.edu/wiki/Annualmeeting:2017_CSDMS_meeting-005>`__

Hobley, D.E.J., Sinclair, H.D., Gasparini, N.M., Tucker, G.E., Cowie,
P.A., Adams\ *, J.M., Hutton, E.W.H., Istanbulluoglu, E., and
Nudurupati*, S.S. (2017, September) How common is nonlinear control of
erosion by sediment flux in natural rivers? Paper presented at British
Society for Geomorphology, Hull, UK.

Langston, A., Tucker, G. (2017) Using a landscape evolution model to
evaluate the role of pulses of uplift on bedrock valley width and
channel mobility, Modeling Coupled Earth and Human Systems - The Dynamic
Duo, Boulder, Colorado, May, 2017.
`abstract <https://csdms.colorado.edu/wiki/Annualmeeting:2017_CSDMS_meeting-128>`__

Langston, A.L., and Tucker, G.E. (2017, December) Working Towards
Interpreting Strath Terraces as Records of Climate Change: Evaluating a
Model of Lateral Bedrock Erosion. Poster presented at American
Geophysical Union fall meeting, New Orleans, LA.

Lyons, N., Gasparini, N. (2017) Numerical simulations of transient
landscape adjustment along the Mendocino Triple Junction, CSDMS Annual
Meeting, Modeling Coupled Earth and Human Systems - The Dynamic Duo,
Boulder, Colorado, May, 2017.
`abstract <https://csdms.colorado.edu/wiki/Annualmeeting:2017_CSDMS_meeting-014>`__

Nudurupati, S.S., Istanbulluoglu, E., Adams, J., Hobley, D., Gasparini,
N., Tucker, G., Hutton, E., Studying the Role of Disturbances on Woody
Plant Encroachment in Southwestern US using a Coupled Landlab
Ecohydrology Model, Modeling Coupled Earth and Human Systems - The
Dynamic Duo, Boulder, Colorado, May, 2017.
`abstract <https://csdms.colorado.edu/wiki/Annualmeeting:2017_CSDMS_meeting-019>`__

Shobe, C.M., Tucker, G.E., Barnhart, K.R. (2017) Exploring river
response to tectonic perturbations with the open source, 2-D SPACE
model, GSA annual meeting, Seattle, Washington, October 2017.
`abstract <https://gsa.confex.com/gsa/2017AM/webprogram/Paper296922.html>`__
`poster <https://figshare.com/articles/_/5547637>`__

Tucker, G.E. (2017, July) Some community resources for modeling
critical-zone dynamics. Webinar presented to Cross-CZO Modeling Series.

Tucker, G.E. (2017, December) How do we test landscape evolution theory?
An example of multi-model assessment using a case study in post-glacial
drainage network incision. Invited lecture at Gilbert Club annual
meeting, New Orleans, Louisiana.

Tucker, G., Adams, J.M., Bandaragoda, C., Barnhart, K.R., Gasparini,
N.M., Hobley, D.E.J., Hutton, E., Istanbulluoglu, E., Knuth, J.,
Mouchene, M., Nudurupati, S.S. (2017) Landlab: Plug-and-play numerical
modeling of Earth-surface dynamics, NSF SI2 PI meeting, Arlington,
Virginia, February 2017
`poster <https://figshare.com/articles/Landlab_Plug-and-play_numerical_modeling_of_Earth-surface_dynamics/4621546>`__

Tucker, G.E., Barnhart, K.R., Glade*, R.C., Shobe, C.M., Doty, S.G., and
Hill, M.C. (2017, July) Using a natural experiment in post-glacial
landscape evolution as a testbed for comparing alternative geomorphic
model formulations. Invited paper presented at CUAHSI HydroInformatics
Conference, Tuscaloosa, AL.

2016
----

Adams, J.M., Gasparini, N.M., Tucker, G.E., and Istanbulluoglu, E.
(2016) Nonsteady flow routing in Landlab: implications for modeling
watershed evolution. Poster presented at AGU Fall Meeting, San
Francisco, California, December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/135152>`__

Gasparini, N.M., Adams, J.M., Hobley, D.E.J., Hutton, E.W.H.,
Nudurupati, S.S., Istanbulluoglu, E., and Tucker, G.E. (2016) Landlab:
an Open-Source Python Library for Modeling Earth Surface Dynamics.
Poster presented at AGU Fall Meeting, San Francisco, California,
December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/149398>`__

Gelb, L., Nudurupati, S.S., Yager, E., Glenn, N.F., Pierce, J., and
Flores, A.N. (2016) Assessing the sensitivity of a water-limited, mixed
tree-grass-shrub ecosystem to climate change and geomorphic controls
using a community modeling framework. Talk presented at AGU Fall
Meeting, San Francisco, California, December 2016.
`abstract  <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/129255>`__

Glaubius, J., and Maerker, M. (2016) Integrating Geomorphic and Social
Dynamics in the Analysis of Anthropogenic Landforms: Examining Landscape
Evolution of Terrain Modified by Agricultural Terracing. Poster
presented at AGU Fall Meeting, San Francisco, California, December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/195142>`__

Langston, A.L., and Tucker, G.E.(2016) Developing and Evaluating a
Theory for Lateral Erosion by Bedrock Channels in a Landscape Evolution
Model. Poster presented at AGU Fall Meeting, San Francisco, California,
December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/144788>`__

Lai, J., and Anders, A.M. (2016) Numerical modeling of the evolution of
fluvial networks on glaciated landscapes. Poster presented at AGU Fall
Meeting, San Francisco, California, December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/168276>`__
:download:`poster <user_guide/images/JingtaoLai_AGU_2016.jpg>`
:download:`dowload poster PDF <user_guide/images/JingtaoLai_AGU_2016.pdf>`

Lynch, B., Yanites, B., Shen, H., and Poulsen, C.J. (2016) Modeling
Landscape Evolution and Climate: How Erosion and Precipitation are
Linked in Active Orogens (Preliminary Results). Poster presented at AGU
Fall Meeting, San Francisco, California, December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/126631>`__

Tucker, G.E., Adams, J.M., Doty, S.G, Gasparini, N.M, Hill, M.C.,
Hobley, D.E.J., Hutton, E., Istanbulluoglu, E., and Nudurupati, S.S.
(2016) Using the Landlab toolkit to evaluate and compare alternative
geomorphic and hydrologic model formulations. Invited talk at AGU Fall
Meeting, San Francisco, California, December 2016.
`abstract <https://agu.confex.com/agu/fm16/meetingapp.cgi/Paper/118620>`__

Adams, J.M. (2016) Integrating a 2-D hydrodynamic model into the Landlab
modeling framework. The Water Institute of the Gulf Seminar Series,
Baton Rouge, Louisiana, September, 2016.

Adams, J.M., Gasparini, N.M., Hobley, D., Tucker, G.E., Hutton, E.W.H.,
Nudurupati, S.S. and Istanbulluoglu, E. (2016) Flooding and erosion
after the Buffalo Creek fire: a modeling approach using Landlab. The
Geological Society of American Annual Meeting, Denver, Colorado, Sept
2016.
`abstract <https://gsa.confex.com/gsa/2016AM/webprogram/Paper285844.html>`__

Adams, J.M., Gasparini, N.M., Hobley, D., Tucker, G.E., Hutton, E.W.H.,
Istanbulluoglu, E., and Nudurupati, S.S. (2016) Integrating a 2-D
hydrodynamic model into the Landlab modeling framework. Paper presented
at CSDMS Annual Meeting: Capturing Climate Change, Boulder, Colorado,
May 2016.
`abstract <https://csdms.colorado.edu/wiki/Presenters-0078>`__

Nudurupati, S.S., Istanbulluoglu, E., Adams, J.M., Hobley, D.,
Gasparini, N.M., Tucker, G.E., and Hutton, E.W.H. (2016) Mechanisms of
Shrub Encroachment explored in Southwestern United States using Landlab
Ecohydrology. Poster presented at CSDMS Annual Meeting: Capturing
Climate Change, Boulder, Colorado, May 2016.
`abstract <https://csdms.colorado.edu/wiki/CSDMS_2016_annual_meeting_poster_SaiSiddharthaNudurupati>`__
:download:`poster <user_guide/images/SaiNudurupati_CSDMS_2016.jpg>`
:download:`dowload poster PDF <user_guide/images/SaiNudurupati_CSDMS_2016.pdf>`

Nudurupati, S.S. (2016) Are All Forest Fires Evil? Lightning talk
presented at the Puget Sound Programming Python (PuPPy) monthly meetup,
Seattle, WA, May 2016.

Hobley, D., Adams, J.M., Gasparini, N.M., Hutton, E.W.H.,
Istanbulluoglu, E., Nudurupati, S.S., and Tucker, G.E. (2016) Landlab: a
new, open-source, modular, Python-based tool for modeling Earth surface
dynamics. Poster presented at EGU General Assembly Meeting, Vienna,
Austria, April 2016.
`abstract <https://meetingorganizer.copernicus.org/EGU2016/EGU2016-9981.pdf>`__
:download:`poster <user_guide/images/EGU_poster_2016.jpg>`
:download:`pdf download <user_guide/images/EGU_poster_2016.pdf>`

Hobley, D., Gasparini, N.M., and Tucker, G.E. (2016) Tools-and-cover
effects in transiently responding mountain rivers: hallmarks and
consequences. Paper presented at EGU General Assembly Meeting, Vienna,
Austria, April 2016.
`abstract <https://meetingorganizer.copernicus.org/EGU2016/EGU2016-9889.pdf>`__

Gasparini, N.M., Adams, J.M., Tucker, G.E., Hobley, D., Hutton, E.W.H.,
Istanbulluoglu, E., and Nudurupati, S.S. (2016) Landlab: A numerical
modeling framework for evolving Earth surfaces from mountains to the
coast. Paper presented at the Ocean Sciences Meeting, New Orleans, LA,
Feb 2016.
`abstract <https://agu.confex.com/agu/os16/meetingapp.cgi/Paper/87020>`__
:download:`poster <user_guide/images/Landlab_OceanSciences2016.jpg>`

Tucker, G.E., Hobley, D.E.J., Gasparini, N.M., Adams, J.M., Nudurupati,
S.S., Istanbulluoglu, E., Hutton, E.W.H., and Knuth, J.S. (2016)
Landlab: A Python library for building and coupling 2D numerical models.
Paper presented at the SI2 Principal Investigators Meeting, Arlington,
VA, Feb 2016.
:download:`poster <user_guide/images/si2pi_landlab_poster_tucker.jpg>`
:download:`download poster <user_guide/images/si2pi_landlab_poster_tucker.pdf>`

2015
----

Adams, J.M., Gasparini, N.M., Tucker, G.E., Hobley, D., Hutton, E.W.H.,
Nudurupati, S.S., and Istanbulluoglu, E. (2015) Modeling overland
flow-driven erosion across a watershed DEM using the Landlab modeling
framework. Paper presented at American Geophysical Union fall meeting,
San Francisco, CA, Dec 2015.
`abstract <https://agu.confex.com/agu/fm15/meetingapp.cgi/Paper/75514>`__
:download:`poster <user_guide/images/Adams_2015_AGUPoster_H13C-1542.jpg>`
`video <https://www.youtube.com/watch?v=4Ltr6HRUrQI>`__

Nudurupati, S.S., Istanbulluoglu, E., Adams, J.M., Hobley, D.,
Gasparini, N.M., Tucker, G.E., and Hutton, E.W.H. (2015) Elevation
Control on Vegetation Organization in a Semiarid Ecosystem in Central
New Mexico. Paper presented at American Geophysical Union fall meeting,
San Francisco, CA, Dec 2015.
`abstract <https://agu.confex.com/agu/fm15/meetingapp.cgi/Paper/80794>`__
:download:`poster <user_guide/images/Sai_AGU_2015.jpg>`

Strauch, R., Istanbulluoglu, E., and Nudurupati, S.S. (2015) Landslide
Hazard from Coupled Inherent and Dynamic Probabilities. Paper presented
at American Geophysical Union fall meeting, San Francisco, CA, Dec 2015.
`abstract <https://agu.confex.com/agu/fm15/meetingapp.cgi/Paper/85607>`__

2014
----

Adams, J.M., Rengers, F.K., Gasparini, N.M., Tucker, G.E., Nudurupati,
S.S., Istanbulluoglu, E., and Hutton, E. (2014) Exploring Post-Wildfire
Hydrologic Response in Central Colorado Using Field Observations and the
Landlab Modeling Framework. Paper presented at American Geophysical
Union Fall Meeting, San Francisco, Dec 2014.
`abstract <https://abstractsearch.agu.org/meetings/2014/FM/EP51E-3562.html>`__
:download:`poster <user_guide/images/Adams_AGU_2014_Poster_small.jpg>`

Gasparini, N.M., Hobley, D.E.J., Tucker, G.E., Istanbulluoglu, E.,
Adams, J.M., Nudurupati, S.S., and Hutton, E. (2014) A Comparison of the
CHILD and Landlab Computational Landscape Evolution Models and Examples
of Best Practices in Numerical Modeling of Surface Processes. Paper
presented at American Geophysical Union Fall Meeting, San Francisco, Dec
2014.
`abstract <https://abstractsearch.agu.org/meetings/2014/FM/EP51E-3564.html>`__

Hobley, D.E.J., Sinclair, H., Gasparini, N.M., Tucker, G.E., Cowie, P.,
Adams, J.M., Hutton, E., Istanbulluoglu, E., and Nudurupati, S.S. (2014)
Elevated Channel Concavities Arising from Sediment-Flux Effects in
Natural Rivers. Paper presented at American Geophysical Union Fall
Meeting, San Francisco, Dec 2014.

Nudurupati, S.S., Istanbulluoglu, E., Adams, J.M., Hobley, D.E.J.,
Gasparini, N.M., Tucker, G.E., and Hutton, E. (2014) Modeling Elevation
and Aspect Controls on Emerging Ecohydrologic Processes and Ecosystem
Patterns Using the Component-based Landlab Framework. Paper presented at
American Geophysical Union Fall Meeting, San Francisco, Dec 2014.

Tucker, G.E., Hobley, D.E.J., and McCoy, S.W. (2014) A model for the
geomorphic development of normal-fault facets. Invited paper presented
at American Geophysical Union Fall Meeting, San Francisco, Dec 2014.

Tucker, G.E., Hobley, D.E.J., Gasparini, N.M., Adams, J.M., Nudurupati,
S.S., Istanbulluoglu, E., and Hutton, E. (2014) Modeling critical-zone
processes with Landlab. Paper presented at Critical Zone Observatories
Annual Meeting, Fish Camp, California, Sept 2014.

Adams, J., Gasparini, N.M., Tucker, G.E., Istanbulluoglu, E., Hutton,
E., Hobley, D., and Nudurupati, S.S. (2014) Modeling hydrologic and
erosional responses of landscapes to fire using the Landlab modeling
environment. 2014: Community Surface Dynamics Modeling System Annual
Meeting, Boulder, Colorado, May 2014.
`abstract <https://csdms.colorado.edu/wiki/CSDMS_2014_annual_meeting_poster_Jordan_Adams>`__
`poster <https://csdms.colorado.edu/wiki/File:CSDMS2014_poster_JordanAdams.pdf>`__

2013
----

Adams, J., Gasparini, N.M., Tucker, G.E., Istanbulluoglu, E., Hutton,
E., Hobley, D., and Nudurupati, S.S. (2013) Modeling wildfire and
hydrologic response to global climate change using the Landlab numerical
model. Paper presented at American Geophysical Union Fall Meeting, San
Francisco, Dec 2013.
`abstract <https://abstractsearch.agu.org/meetings/2013/FM/GC21C-0847.html>`__

Hobley, D.E.J., Tucker, G.E., Adams, J.M., Gasparini, N.M., Hutton, E.,
Istanbulluoglu, E., and Nudurupati, S.S. (2013) Modeling impact
cratering as a geomorphic process using the novel landscape evolution
model Landlab. Paper presented at American Geophysical Union fall
meeting, San Francisco, Dec 2013.

Nudurupati, S.S., Istanbulluoglu, E., Adams, J.M., Gasparini, N.M.,
Tucker, G.E., Hutton, E., and Hobley, D.E.J. (2013) Landlab
ecohydrology: a component-based computational environment for
ecohydrologic modeling and its illustrations through model building.
Paper presented at American Geophysical Union fall meeting, San
Francisco, Dec 2013.

Tucker, G.E., Hobley, D.E.J., Gasparini, N.M., Hutton, E.,
Istanbulluoglu, E., Nudurupati, S.S., and Adams, J. (2013) Create
computing with Landlab: open-source Python software for building and
exploring 2D models of earth-surface dynamics. Paper presented at
American Geophysical Union fall meeting, San Francisco, Dec 2013.

Hobley, D.E.J., Tucker, G.E., Adams, J.M., Gasparini, N.M., Hutton, E.,
Istanbulluoglu, E., and Nudurupati, S.S. (2013) Landlab – a new,
open-source, modular, Python-based tool for modeling landscape dynamics.
Paper presented at Geological Society of America annual meeting, Denver,
Colorado, Oct 2013.

Gasparini, N.M., Tucker, G.E., Istanbulluoglu, E., Hutton, E., Hobley,
D.E.J., and Nudurupati, S. (2013) Landlab: a component-based software
modeling environment for computational Earth-surface processes modeling.
Paper presented at Community Surface Dynamics Modeling System annual
meeting, Boulder, Colorado, Mar 2013.

Nudurupati, S.S., Istanbulluoglu, E., Tucker, G.E., Gasparini, N.M.,
Hutton, E., and Hobley, D.E.J. (2013) Integration of an 'Eco-hydrologic
Component' to a Generic Gridding Engine for 2D Modeling of Earth-Surface
Dynamics. Paper presented at Community Surface Dynamics Modeling System
annual meeting, Boulder, Colorado, Mar 2013.

Tucker, G.E., Gasparini, N.M., Istanbulluoglu, E., Hutton, E., and
Hobley, D.E.J. (2013) A generic "gridding engine" for 2D modeling of
earth-surface dynamics. Paper presented at Community Surface Dynamics
Modeling System annual meeting, Boulder, Colorado, Mar 2013.


.. _clinics_workshops:

---------------------
Clinics and Workshops
---------------------

2020
----

**Exploring Surface Processes using CSDMS Modeling Tools: How to Build Coupled Models**
An online short course on model coupling
presented by G. Tucker, B. Campforts, E. Hutton, and M. Piper
at the 2020 GSA Annual Meeting, October 23. `Presentation and code <GSA 2020>`__

.. _GSA 2020: https://github.com/csdms/gsa-2020

**University of Texas Jackson School of Geosciences Landlab Clinic 2020**
A Landlab clinic presented by N. Gasparini at UT-Austin on September 10, 2020.
`Presentation and code <UT 2020>`__

.. _UT 2020: https://github.com/landlab/UT_Landlab_Clinic

**Exploring Surface Processes using CSDMS Tools: How to Build Coupled Models**
An online workshop on model coupling
presented by E. Hutton, M. Piper, G. Tucker, and I. Overeem
at the 2020 CSDMS Annual Meeting, May 20-21.
`Presentation and code <CSDMS 2020>`__

.. _CSDMS 2020: https://github.com/csdms/csdms-2020

**Penn State Landlab Clinic 2020**
A Landlab clinic presented by N. Gasparini at Penn State on January 22, 2020.
`Presentation and code <Penn 2020>`__

.. _Penn 2020: https://github.com/landlab/psu-clinic-2020

2019
----

**Exploring Surface Processes: How to Build Coupled Models**
A hands-on workshop presented by A. Ashton, N. Gasparini, N. Lyons, I. Overeem, and M. Piper
at the 2019 AGU Fall Meeting in San Francisco, CA.
`Presentation and code <AGU 2019>`__

.. _AGU 2019: https://github.com/csdms/agu-2019

**River, Coastal and Estuarine Morphodynamics (RCEM) Symposium**
A hands-on workshop presented by K. Barnhart, E. Hutton, and G. Tucker
at RCEM 2019, November 16-21 in Auckland, New Zealand.
`Presentation and code <RCEM 2019>`__

.. _RCEM 2019: https://github.com/csdms/rcem-2019

**UW Waterhackweek (Mar 2019): Landlab Modeling Framework and Use Cases**
Presented by S.S. Nudurupati, A. Manaster, C. Bandaragoda, and E.
Istanbulluoglu.
`View cyberseminar online <https://www.youtube.com/watch?v=m10UA5_gsuM&feature=youtu.be>`_,
`Waterhackweek 2019 Landlab materials on HydroShare <https://www.hydroshare.org/resource/0e005873929f41818dd1371da292ba07/>`_

2018
----

**CSDMS Webinar (Sep 2018): Overview of the Landlab Toolkit**
Presented by G. Tucker.
`View webinar online <https://csdms.colorado.edu/wiki/Presenters-0407>`_

**Modeling with the Landlab toolkit**
Presented by N. Gasparini at the 2018 Summer Institute on Earth-Surface
Dynamics on 26 July in Minneapolis, MN.
`Presentation and code <https://github.com/landlab/nced_summer_instititute_2018>`__

**GeoHazardSilesia 2018: Building numerical models to explore geohazard hypotheses**
Lyons, N.J. (2018) Short course at GeoHazardSilesia 2018, Katowice,
Poland, 5–9 June, 2018.
`Course website <https://sites.google.com/view/geohazard-numerical-models>`_

**CSDMS May 2018: Landlab with Hydroshare**
Mouchene, M., Gasparini, N.M. and Adams, J.M. (2018) Landlab with
Hydroshare. Clinic presented at CSDMS Annual Meeting: Geoprocesses,
Geohazards, Boulder, Colorado, May 2018.
`CSDMS 2018 slides and files on Hydroshare <https://www.hydroshare.org/resource/4c74e1630fef4f55b94c8645be63ae9d/>`_

**CSDMS May 2018: Model sensitivity analysis and optimization with Dakota and Landlab**
Barnhart, K.R. (2018) Model sensitivity analysis and optimization with
Dakota and Landlab. Clinic presented at CSDMS Annual Meeting:
Geoprocesses, Geohazards, Boulder, Colorado, May 2018.
`CSDMS 2018 Landlab and Dakota clinic materials on HydroShare <https://www.hydroshare.org/resource/ea0952c7a16b42468822a78db3de5a4b/>`_

2017
----

**GSA Oct 2017: Landlab Earth Surface Modeling Toolkit: Building and Applying Models of Coupled Earth Surface Processes**
Bandaragoda, C., Istanbulluoglu, E., Nudurupati, S. S., Manaster, A.,
Strauch, R., Lyons, N., and Phuong, J. (2017). Landlab Earth Surface
Modeling Toolkit: Building and Applying Models of Coupled Earth Surface
Processes. Short-course presented at GSA 2017, Seattle, Washington,
October 2017
`GSA 2017 Landlab short-course material on HydroShare <https://www.hydroshare.org/accounts/login/?next=/resource/3ab2e7d190c44a70b62f96a3c0b1b627/>`_

**CSDMS May 2017: Modeling Earth-Surface Dynamics with Landlab 1.0**
Gasparini, N.M., Adams, J.M., Nudurupati, S.S., Istanbulluoglu, E.,
Barnhart, K.R. and Mouchene, M. (2017) Modeling Earth-Surface Dynamics
with Landlab 1.0. Clinic presented at CSDMS Annual Meeting: Modeling
Coupled Earth and Human Systems - the Dynamic Duo, Boulder, Colorado,
May 2017.
`CSDMS 2017 Landlab clinic materials on HydroShare <https://www.hydroshare.org/resource/2610b5c20e9049b4b6d8c11505d931b5/>`_
`CSDMS 2017 Landlab clinic materials on GitHub <https://github.com/landlab/csdms_model_clinic_may_2017>`_

**CSDMS May 2017: Model sensitivity analysis and optimization with Dakota and Landlab**
Barnhart, K.R. (2017) Model sensitivity analysis and optimization with
Dakota and Landlab. Clinic presented at CSDMS Annual Meeting: Modeling
Coupled Earth and Human Systems - the Dynamic Duo, Boulder, Colorado,
May 2017.
`CSDMS 2017 Landlab and Dakota clinic materials on HydroShare <https://www.hydroshare.org/resource/ea0952c7a16b42468822a78db3de5a4b/>`_

2016
----

**CSDMS May 2016: Modeling Earth-Surface Dynamics with Landlab**
Tucker, G.E., Hobley, D., Nudurupati, S.S., Adams, J.M., Hutton, E.,
Gasparini, N.M., and Istanbulluoglu, E. (2016) Modeling Earth-Surface
Dynamics with Landlab. Clinic presented at CSDMS Annual Meeting:
Capturing Climate Change, Boulder, Colorado, May 2016.
:download:`download the clinic slides <user_guide/images/landlab_clinic_csdms_may2016.pdf>`

**CUAHSI Biennial Meeting, July 2016: Modeling landscape response using big data with Landlab**
Istanbulluoglu E., Nudurupati S.S., Strauch R., and Bandaragoda C.
(2016). Modeling Landscape Response using Big Data with Landlab.
Workshop presented at CUAHSI Biennial Symposium, July 24-27,
Shepherdstown, WV.
`CUAHSI 2016 Landlab workshop resources <https://github.com/landlab/CUAHSI_Biennial_July_2016>`_

**U Houston, September 2016, Modeling Earth-Surface Dynamics with Landlab**
Gasparini, N.M. and Adams, J.M. (2016) Modeling Earth-Surface Dynamics
with Landlab. Clinic presented at the University of Houston, Department
of Earth and Atmospheric Sciences, Houston, Texas, September 2016.
:download:`download the clinic slides <user_guide/images/landlab_clinic_houston_sep2016.pdf>`

2015
----

**CSDMS May 2015: Landlab: A Python library for 2D numerical modeling**
Tucker, G.E., Hobley, D., Nudurupati, S.S., Adams, J.M., Hutton, E.,
Gasparini, N.M., and Istanbulluoglu, E. (2015) Landlab: A Python library
for 2D numerical modeling. Clinic presented at CSDMS Annual Meeting:
Models meet Data, Data meet Models, Boulder, Colorado, May 2015.
`CSDMS 2015 Landlab clinic materials on GitHub <https://github.com/landlab/csdms_meeting_may_2015>`_
